@@ -1,10 +1,9 @@
 # --
-# Kernel/GenericInterface/Mapping/Simple.pm - GenericInterface simple data mapping backend
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::GenericInterface::Mapping::Simple;
@@ -81,7 +80,7 @@ sub new {
 =item Map()
 
 provides 1:1 and regex mapping for keys and values
-also the use of a default for unmapped keys and values is possible
+also the use of a default for keys and values that were not mapped is possible
 
 we need the config to be in the following format
 
@@ -102,7 +101,7 @@ we need the config to be in the following format
                                    # 'MapTo' (use provided value as default)
             MapTo => 'new_value',  # only used if 'MapType' is 'MapTo'. then required
         },
-        ValueMap => {
+        ValueMap => {              # optional.
             'new_key_name' => {    # optional. Replacement for a specific key
                 ValueMapExact => { # optional. key/value pairs for direct replacement
                     'old_value'         => 'new_value',
@@ -244,7 +243,11 @@ sub Map {
         }
 
         # check if we have a value mapping for the specific key
-        my $ValueMap = $Config->{ValueMap}->{$NewKey};
+        my $ValueMap;
+        if ( $Config->{ValueMap} && $Config->{ValueMap}->{$NewKey} ) {
+            $ValueMap = $Config->{ValueMap}->{$NewKey};
+        }
+
         if ($ValueMap) {
 
             # first check in exact (1:1) map
@@ -414,42 +417,44 @@ sub _ConfigCheck {
     }
 
     # check ValueMap
-    for my $KeyName ( sort keys %{ $Config->{ValueMap} } ) {
+    if ( IsHashRefWithData( $Config->{ValueMap} ) ) {
+        for my $KeyName ( sort keys %{ $Config->{ValueMap} } ) {
 
-        # require values to be hash ref
-        if ( !IsHashRefWithData( $Config->{ValueMap}->{$KeyName} ) ) {
-            return $Self->{DebuggerObject}->Error(
-                Summary => "Got $KeyName in ValueMap, but it is no hash ref with content!",
-            );
-        }
-
-        # possible sub-values are ValueMapExact or ValueMapRegEx and need to be hash ref if defined
-        SUBKEY:
-        for my $SubKeyName (qw(ValueMapExact ValueMapRegEx)) {
-            my $ValueMapType = $Config->{ValueMap}->{$KeyName}->{$SubKeyName};
-            next SUBKEY if !defined $ValueMapType;
-            if ( !IsHashRefWithData($ValueMapType) ) {
+            # require values to be hash ref
+            if ( !IsHashRefWithData( $Config->{ValueMap}->{$KeyName} ) ) {
                 return $Self->{DebuggerObject}->Error(
-                    Summary =>
-                        "Got $SubKeyName in $KeyName in ValueMap,"
-                        . ' but it is no hash ref with content!',
+                    Summary => "Got $KeyName in ValueMap, but it is no hash ref with content!",
                 );
             }
 
-            # key/value pairs of ValueMapExact and ValueMapRegEx must be strings
-            for my $ValueMapTypeKey ( sort keys %{$ValueMapType} ) {
-                if ( !IsString($ValueMapTypeKey) ) {
+            # possible sub-values are ValueMapExact or ValueMapRegEx and need to be hash ref if defined
+            SUBKEY:
+            for my $SubKeyName (qw(ValueMapExact ValueMapRegEx)) {
+                my $ValueMapType = $Config->{ValueMap}->{$KeyName}->{$SubKeyName};
+                next SUBKEY if !defined $ValueMapType;
+                if ( !IsHashRefWithData($ValueMapType) ) {
                     return $Self->{DebuggerObject}->Error(
                         Summary =>
-                            "Got key in $SubKeyName in $KeyName in ValueMap which is not a string!",
+                            "Got $SubKeyName in $KeyName in ValueMap,"
+                            . ' but it is no hash ref with content!',
                     );
                 }
-                if ( !IsString( $ValueMapType->{$ValueMapTypeKey} ) ) {
-                    return $Self->{DebuggerObject}->Error(
-                        Summary =>
-                            "Got value for $ValueMapTypeKey in $SubKeyName in $KeyName in ValueMap"
-                            . ' which is not a string!',
-                    );
+
+                # key/value pairs of ValueMapExact and ValueMapRegEx must be strings
+                for my $ValueMapTypeKey ( sort keys %{$ValueMapType} ) {
+                    if ( !IsString($ValueMapTypeKey) ) {
+                        return $Self->{DebuggerObject}->Error(
+                            Summary =>
+                                "Got key in $SubKeyName in $KeyName in ValueMap which is not a string!",
+                        );
+                    }
+                    if ( !IsString( $ValueMapType->{$ValueMapTypeKey} ) ) {
+                        return $Self->{DebuggerObject}->Error(
+                            Summary =>
+                                "Got value for $ValueMapTypeKey in $SubKeyName in $KeyName in ValueMap"
+                                . ' which is not a string!',
+                        );
+                    }
                 }
             }
         }
@@ -469,10 +474,10 @@ sub _ConfigCheck {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
