@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Modules::AdminSMIME;
@@ -11,8 +11,9 @@ package Kernel::Modules::AdminSMIME;
 use strict;
 use warnings;
 
-use Kernel::System::Crypt;
-use Kernel::System::CustomerUser;
+use Kernel::Language qw(Translatable);
+
+our $ObjectManagerDisabled = 1;
 
 sub new {
     my ( $Type, %Param ) = @_;
@@ -21,33 +22,83 @@ sub new {
     my $Self = {%Param};
     bless( $Self, $Type );
 
-    # check all needed objects
-    for my $Needed (
-        qw(ParamObject DBObject LayoutObject ConfigObject LogObject MainObject EncodeObject)
-        )
-    {
-        if ( !$Self->{$Needed} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
-        }
-    }
-
-    $Self->{CryptObject} = Kernel::System::Crypt->new( %Param, CryptType => 'SMIME' );
-    $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
-
     return $Self;
 }
 
 sub Run {
     my ( $Self, %Param ) = @_;
 
-    $Param{Search} = $Self->{ParamObject}->GetParam( Param => 'Search' );
+    # get objects
+    my $ParamObject  = $Kernel::OM->Get('Kernel::System::Web::Request');
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    # ------------------------------------------------------------ #
+    # check if feature is active
+    # ------------------------------------------------------------ #
+    if ( !$Kernel::OM->Get('Kernel::Config')->Get('SMIME') ) {
+
+        my $Output .= $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+
+        $LayoutObject->Block( Name => 'Overview' );
+        $LayoutObject->Block( Name => 'Notice' );
+        $LayoutObject->Block( Name => 'Disabled' );
+        $LayoutObject->Block( Name => 'OverviewResult' );
+        $LayoutObject->Block(
+            Name => 'NoDataFoundMsg',
+            Data => {},
+        );
+
+        $Output .= $LayoutObject->Output( TemplateFile => 'AdminSMIME' );
+        $Output .= $LayoutObject->Footer();
+
+        return $Output;
+    }
+
+    # get SMIME objects
+    my $SMIMEObject = $Kernel::OM->Get('Kernel::System::Crypt::SMIME');
+
+    if ( !$SMIMEObject ) {
+
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
+
+        $Output .= $LayoutObject->Notify(
+            Priority => 'Error',
+            Data     => Translatable("S/MIME environment is not working. Please check log for more info!"),
+            Link     => $LayoutObject->{Baselink} . 'Action=AdminLog',
+        );
+
+        $LayoutObject->Block( Name => 'Overview' );
+        $LayoutObject->Block( Name => 'Notice' );
+        $LayoutObject->Block( Name => 'NotWorking' );
+        $LayoutObject->Block( Name => 'OverviewResult' );
+        $LayoutObject->Block(
+            Name => 'NoDataFoundMsg',
+            Data => {},
+        );
+
+        $Output .= $LayoutObject->Output(
+            TemplateFile => 'AdminSMIME',
+        );
+
+        $Output .= $LayoutObject->Footer();
+
+        return $Output;
+    }
+
+    $Param{Search} = $ParamObject->GetParam( Param => 'Search' );
     if ( !defined $Param{Search} ) {
         $Param{Search} = $Self->{SMIMESearch} || '';
     }
     if ( $Self->{Subaction} eq '' ) {
         $Param{Search} = '';
     }
-    $Self->{SessionObject}->UpdateSessionID(
+
+    # get session object
+    my $SessionObject = $Kernel::OM->Get('Kernel::System::AuthSession');
+
+    $SessionObject->UpdateSessionID(
         SessionID => $Self->{SessionID},
         Key       => 'SMIMESearch',
         Value     => $Param{Search},
@@ -59,13 +110,13 @@ sub Run {
     if ( $Self->{Subaction} eq 'Delete' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        my $Filename = $Self->{ParamObject}->GetParam( Param => 'Filename' ) || '';
-        my $Type     = $Self->{ParamObject}->GetParam( Param => 'Type' )     || '';
+        my $Filename = $ParamObject->GetParam( Param => 'Filename' ) || '';
+        my $Type     = $ParamObject->GetParam( Param => 'Type' )     || '';
         if ( !$Filename ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => 'Need param Filename to delete!',
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('Need param Filename to delete!'),
             );
         }
 
@@ -74,18 +125,18 @@ sub Run {
 
         # remove private key
         if ( $Type eq 'key' ) {
-            %Result = $Self->{CryptObject}->PrivateRemove( Filename => $Filename );
+            %Result = $SMIMEObject->PrivateRemove( Filename => $Filename );
             push @Result, \%Result if %Result;
         }
 
         # remove certificate and private key if exists
         else {
-            my $Certificate = $Self->{CryptObject}->CertificateGet( Filename => $Filename );
-            my %Attributes = $Self->{CryptObject}->CertificateAttributes(
+            my $Certificate = $SMIMEObject->CertificateGet( Filename => $Filename );
+            my %Attributes  = $SMIMEObject->CertificateAttributes(
                 Certificate => $Certificate,
             );
 
-            %Result = $Self->{CryptObject}->CertificateRemove( Filename => $Filename );
+            %Result = $SMIMEObject->CertificateRemove( Filename => $Filename );
             push @Result, \%Result if %Result;
 
             # delete certificate from customer preferences
@@ -93,7 +144,8 @@ sub Run {
 
                 # check if there are customers that have assigned the certificate in their
                 # preferences
-                my %UserList = $Self->{CustomerUserObject}->SearchPreferences(
+                my $CustomerUserObject = $Kernel::OM->Get('Kernel::System::CustomerUser');
+                my %UserList           = $CustomerUserObject->SearchPreferences(
                     Key   => 'SMIMEFilename',
                     Value => $Filename,
                 );
@@ -103,13 +155,13 @@ sub Run {
 
                     # reset all SMIME preferences for the customer
                     for my $PreferenceKey (qw(SMIMEHash SMIMEFingerprint SMIMEFilename)) {
-                        my $Success = $Self->{CustomerUserObject}->SetPreferences(
+                        my $Success = $CustomerUserObject->SetPreferences(
                             Key    => $PreferenceKey,
                             Value  => '',
                             UserID => $UserID,
                         );
                         if ( !$Success ) {
-                            $Self->{LogObject}->Log(
+                            $Kernel::OM->Get('Kernel::System::Log')->Log(
                                 Priority => 'error',
                                 Message =>
                                     "Could not reset preference $PreferenceKey for customer $UserID",
@@ -120,21 +172,21 @@ sub Run {
             }
 
             if ( defined $Attributes{Private} && $Attributes{Private} eq 'Yes' ) {
-                %Result = $Self->{CryptObject}->PrivateRemove( Filename => $Filename );
+                %Result = $SMIMEObject->PrivateRemove( Filename => $Filename );
                 push @Result, \%Result if %Result;
             }
         }
 
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
 
         $Output .= $Self->_Overview( Result => \@Result );
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminSMIME',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
         return $Output;
     }
 
@@ -154,15 +206,15 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'AddCertificate' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
-        $Self->{SessionObject}->UpdateSessionID(
+        $SessionObject->UpdateSessionID(
             SessionID => $Self->{SessionID},
             Key       => 'SMIMESearch',
             Value     => '',
         );
 
-        my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
+        my %UploadStuff = $ParamObject->GetUploadAll(
             Param => 'FileUpload',
         );
 
@@ -177,22 +229,22 @@ sub Run {
         if ( !%Errors ) {
 
             # add certificate
-            my %Result = $Self->{CryptObject}->CertificateAdd( Certificate => $UploadStuff{Content} );
+            my %Result = $SMIMEObject->CertificateAdd( Certificate => $UploadStuff{Content} );
             my @Result;
             push @Result, \%Result if %Result;
 
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
+            my $Output = $LayoutObject->Header();
+            $Output .= $LayoutObject->NavigationBar();
 
             $Output .= $Self->_Overview(
                 Result => \@Result,
             );
 
-            $Output .= $Self->{LayoutObject}->Output(
+            $Output .= $LayoutObject->Output(
                 TemplateFile => 'AdminSMIME',
                 Data         => \%Param,
             );
-            $Output .= $Self->{LayoutObject}->Footer();
+            $Output .= $LayoutObject->Footer();
             return $Output;
         }
 
@@ -220,18 +272,18 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'AddPrivate' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
         my ( %GetParam, %Errors );
 
-        $GetParam{Secret} = $Self->{ParamObject}->GetParam( Param => 'Secret' ) || '';
+        $GetParam{Secret} = $ParamObject->GetParam( Param => 'Secret' ) || '';
 
-        $Self->{SessionObject}->UpdateSessionID(
+        $SessionObject->UpdateSessionID(
             SessionID => $Self->{SessionID},
             Key       => 'SMIMESearch',
             Value     => '',
         );
-        my %UploadStuff = $Self->{ParamObject}->GetUploadAll(
+        my %UploadStuff = $ParamObject->GetUploadAll(
             Param => 'FileUpload',
         );
 
@@ -244,7 +296,7 @@ sub Run {
         if ( !%Errors ) {
 
             # add private key
-            my %Result = $Self->{CryptObject}->PrivateAdd(
+            my %Result = $SMIMEObject->PrivateAdd(
                 Private => $UploadStuff{Content},
                 Secret  => $GetParam{Secret},
             );
@@ -252,18 +304,18 @@ sub Run {
             my @Result;
             push @Result, \%Result if %Result;
 
-            my $Output = $Self->{LayoutObject}->Header();
-            $Output .= $Self->{LayoutObject}->NavigationBar();
+            my $Output = $LayoutObject->Header();
+            $Output .= $LayoutObject->NavigationBar();
 
             $Output .= $Self->_Overview(
                 Result => \@Result,
             );
 
-            $Output .= $Self->{LayoutObject}->Output(
+            $Output .= $LayoutObject->Output(
                 TemplateFile => 'AdminSMIME',
                 Data         => \%Param,
             );
-            $Output .= $Self->{LayoutObject}->Footer();
+            $Output .= $LayoutObject->Footer();
             return $Output;
         }
 
@@ -279,19 +331,19 @@ sub Run {
     # download fingerprint
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'DownloadFingerprint' ) {
-        my $Filename = $Self->{ParamObject}->GetParam( Param => 'Filename' ) || '';
+        my $Filename = $ParamObject->GetParam( Param => 'Filename' ) || '';
         if ( !$Filename ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => 'Need param Filename to download!',
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('Need param Filename to download!'),
             );
         }
 
         my $Hash = $Filename;
         $Hash =~ s{(.+)\.\d}{$1}xms;
 
-        my $Certificate = $Self->{CryptObject}->CertificateGet( Filename => $Filename );
-        my %Attributes = $Self->{CryptObject}->CertificateAttributes( Certificate => $Certificate );
-        return $Self->{LayoutObject}->Attachment(
+        my $Certificate = $SMIMEObject->CertificateGet( Filename => $Filename );
+        my %Attributes = $SMIMEObject->CertificateAttributes( Certificate => $Certificate );
+        return $LayoutObject->Attachment(
             ContentType => 'text/plain',
             Content     => $Attributes{Fingerprint},
             Filename    => "$Hash.txt",
@@ -303,12 +355,12 @@ sub Run {
     # download key
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Download' ) {
-        my $Filename = $Self->{ParamObject}->GetParam( Param => 'Filename' ) || '';
+        my $Filename = $ParamObject->GetParam( Param => 'Filename' ) || '';
 
-        my $Type = $Self->{ParamObject}->GetParam( Param => 'Type' ) || '';
+        my $Type = $ParamObject->GetParam( Param => 'Type' ) || '';
         if ( !$Filename ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => 'Need param Filename to download!',
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('Need param Filename to download!'),
             );
         }
 
@@ -320,14 +372,14 @@ sub Run {
         # download key
         if ( $Type eq 'key' ) {
             my $Secret;
-            ( $Download, $Secret ) = $Self->{CryptObject}->PrivateGet( Filename => $Filename );
+            ( $Download, $Secret ) = $SMIMEObject->PrivateGet( Filename => $Filename );
         }
 
         # download certificate
         else {
-            $Download = $Self->{CryptObject}->CertificateGet( Filename => $Filename );
+            $Download = $SMIMEObject->CertificateGet( Filename => $Filename );
         }
-        return $Self->{LayoutObject}->Attachment(
+        return $LayoutObject->Attachment(
             ContentType => 'text/plain',
             Content     => $Download,
             Filename    => "$Hash.pem",
@@ -341,7 +393,7 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'SignerRelations' ) {
 
         # look for needed parameters
-        my $CertFingerprint = $Self->{ParamObject}->GetParam( Param => 'Fingerprint' ) || '';
+        my $CertFingerprint = $ParamObject->GetParam( Param => 'Fingerprint' ) || '';
         my $Output = $Self->_SignerCertificateOverview( CertFingerprint => $CertFingerprint );
 
         return $Output;
@@ -353,20 +405,20 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'SignerRelationAdd' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
         # look for needed parameters
-        my $CertFingerprint = $Self->{ParamObject}->GetParam( Param => 'CertFingerprint' ) || '';
-        my $CAFingerprint   = $Self->{ParamObject}->GetParam( Param => 'CAFingerprint' )   || '';
+        my $CertFingerprint = $ParamObject->GetParam( Param => 'CertFingerprint' ) || '';
+        my $CAFingerprint   = $ParamObject->GetParam( Param => 'CAFingerprint' )   || '';
 
         if ( !$CertFingerprint || !$CAFingerprint ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => 'Needed CertFingerprint and CAFingerprint',
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('Needed CertFingerprint and CAFingerprint!'),
             );
         }
 
         # relation already exists?
-        my $Exists = $Self->{CryptObject}->SignerCertRelationExists(
+        my $Exists = $SMIMEObject->SignerCertRelationExists(
             CertFingerprint => $CertFingerprint,
             CAFingerprint   => $CAFingerprint,
         );
@@ -376,12 +428,12 @@ sub Run {
         my $Output;
         if ( $CertFingerprint eq $CAFingerprint ) {
             $Message{Priority} = 'Error';
-            $Message{Message}  = 'CAFingerprint must be different than CertFingerprint';
+            $Message{Message}  = Translatable('CAFingerprint must be different than CertFingerprint');
             $Error             = 1;
         }
         elsif ($Exists) {
             $Message{Priority} = 'Error';
-            $Message{Message}  = 'Relation exists!';
+            $Message{Message}  = Translatable('Relation exists!');
             $Error             = 1;
         }
 
@@ -392,7 +444,7 @@ sub Run {
             );
         }
         else {
-            my $Result = $Self->{CryptObject}->SignerCertRelationAdd(
+            my $Result = $SMIMEObject->SignerCertRelationAdd(
                 CertFingerprint => $CertFingerprint,
                 CAFingerprint   => $CAFingerprint,
                 UserID          => $Self->{UserID},
@@ -400,11 +452,11 @@ sub Run {
 
             if ($Result) {
                 $Message{Priority} = 'Notify';
-                $Message{Message}  = 'Relation added!';
+                $Message{Message}  = Translatable('Relation added!');
             }
             else {
                 $Message{Priority} = 'Error';
-                $Message{Message}  = 'Imposible to add relation!';
+                $Message{Message}  = Translatable('Impossible to add relation!');
             }
 
             $Output = $Self->_SignerCertificateOverview(
@@ -422,20 +474,20 @@ sub Run {
     elsif ( $Self->{Subaction} eq 'SignerRelationDelete' ) {
 
         # challenge token check for write action
-        $Self->{LayoutObject}->ChallengeTokenCheck();
+        $LayoutObject->ChallengeTokenCheck();
 
         # look for needed parameters
-        my $CertFingerprint = $Self->{ParamObject}->GetParam( Param => 'CertFingerprint' ) || '';
-        my $CAFingerprint   = $Self->{ParamObject}->GetParam( Param => 'CAFingerprint' )   || '';
+        my $CertFingerprint = $ParamObject->GetParam( Param => 'CertFingerprint' ) || '';
+        my $CAFingerprint   = $ParamObject->GetParam( Param => 'CAFingerprint' )   || '';
 
         if ( !$CertFingerprint && !$CAFingerprint ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => 'Needed CertFingerprint and CAFingerprint!',
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('Needed CertFingerprint and CAFingerprint!'),
             );
         }
 
         # relation exists?
-        my $Exists = $Self->{CryptObject}->SignerCertRelationExists(
+        my $Exists = $SMIMEObject->SignerCertRelationExists(
             CertFingerprint => $CertFingerprint,
             CAFingerprint   => $CAFingerprint,
         );
@@ -445,7 +497,7 @@ sub Run {
         my $Output;
         if ( !$Exists ) {
             $Message{Priority} = 'Error';
-            $Message{Message}  = 'Relation doesn\'t exists';
+            $Message{Message}  = Translatable('Relation doesn\'t exists');
             $Error             = 1;
         }
 
@@ -456,7 +508,7 @@ sub Run {
             );
         }
         else {
-            my $Success = $Self->{CryptObject}->SignerCertRelationDelete(
+            my $Success = $SMIMEObject->SignerCertRelationDelete(
                 CertFingerprint => $CertFingerprint,
                 CAFingerprint   => $CAFingerprint,
                 UserID          => $Self->{UserID},
@@ -464,11 +516,11 @@ sub Run {
 
             if ($Success) {
                 $Message{Priority} = 'Notify';
-                $Message{Message}  = 'Relation deleted!';
+                $Message{Message}  = Translatable('Relation deleted!');
             }
             else {
                 $Message{Priority} = 'Error';
-                $Message{Message}  = 'Imposible to delete relation!';
+                $Message{Message}  = Translatable('Impossible to delete relation!');
             }
 
             $Output = $Self->_SignerCertificateOverview(
@@ -484,18 +536,21 @@ sub Run {
     # read certificate
     # ------------------------------------------------------------ #
     elsif ( $Self->{Subaction} eq 'Read' ) {
-        my $Filename = $Self->{ParamObject}->GetParam( Param => 'Filename' ) || '';
+        my $Filename = $ParamObject->GetParam( Param => 'Filename' ) || '';
         if ( !$Filename ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => 'Need param Filename to download!'
+            return $LayoutObject->ErrorScreen(
+                Message => Translatable('Need param Filename to download!'),
             );
         }
 
         my $Output = $Self->_CertificateRead( Filename => $Filename );
 
         if ( !$Output ) {
-            return $Self->{LayoutObject}->ErrorScreen(
-                Message => "Certificate $Filename could not be read!"
+            return $LayoutObject->ErrorScreen(
+                Message => $LayoutObject->{LanguageObject}->Translate(
+                    'Certificate %s could not be read!',
+                    $Filename
+                ),
             );
         }
 
@@ -506,16 +561,16 @@ sub Run {
     # overview
     # ------------------------------------------------------------ #
     else {
-        my $Output = $Self->{LayoutObject}->Header();
-        $Output .= $Self->{LayoutObject}->NavigationBar();
+        my $Output = $LayoutObject->Header();
+        $Output .= $LayoutObject->NavigationBar();
 
         $Output .= $Self->_Overview() || '';
 
-        $Output .= $Self->{LayoutObject}->Output(
+        $Output .= $LayoutObject->Output(
             TemplateFile => 'AdminSMIME',
             Data         => \%Param,
         );
-        $Output .= $Self->{LayoutObject}->Footer();
+        $Output .= $LayoutObject->Footer();
         return $Output;
     }
 }
@@ -523,32 +578,32 @@ sub Run {
 sub _MaskAdd {
     my ( $Self, %Param ) = @_;
 
-    $Self->{LayoutObject}->Block(
-        Name => 'ActionList',
-    );
-    $Self->{LayoutObject}->Block(
-        Name => 'ActionOverview',
-    );
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
 
-    # show the right dtl block
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block( Name => 'Overview' );
+    $LayoutObject->Block( Name => 'ActionList' );
+    $LayoutObject->Block( Name => 'ActionOverview' );
+
+    # show the right tt block
+    $LayoutObject->Block(
         Name => 'OverviewAdd' . $Param{Type},
         Data => \%Param,
     );
 
-    my $Output = $Self->{LayoutObject}->Header();
+    my $Output = $LayoutObject->Header();
     $Output .= $Param{Message}
-        ? $Self->{LayoutObject}->Notify(
+        ? $LayoutObject->Notify(
         Priority => 'Error',
         Info     => $Param{Message},
         )
         : '';
-    $Output .= $Self->{LayoutObject}->NavigationBar();
-    $Self->{LayoutObject}->Block( Name => 'Hint' );
-    $Output .= $Self->{LayoutObject}->Output(
+    $Output .= $LayoutObject->NavigationBar();
+    $LayoutObject->Block( Name => 'Hint' );
+    $Output .= $LayoutObject->Output(
         TemplateFile => 'AdminSMIME',
     );
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $LayoutObject->Footer();
     return $Output;
 }
 
@@ -557,61 +612,31 @@ sub _Overview {
 
     my $Output;
 
-    # check if SMIME is activated in the sysconfig first
-    if ( !$Self->{ConfigObject}->Get('SMIME') ) {
-        $Output .= $Self->{LayoutObject}->Notify(
-            Priority => 'Error',
-            Data     => $Self->{LayoutObject}->{LanguageObject}->Translate( "Please activate %s first!", "SMIME" ),
-            Link =>
-                $Self->{LayoutObject}->{Baselink}
-                . 'Action=AdminSysConfig;Subaction=Edit;SysConfigGroup=Framework;SysConfigSubGroup=Crypt::SMIME',
-        );
-    }
+    # get needed objects
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+    my $SMIMEObject  = $Kernel::OM->Get('Kernel::System::Crypt::SMIME');
 
-    # check if SMIME Paths are writable
-    for my $PathKey (qw(SMIME::CertPath SMIME::PrivatePath)) {
-        if ( !-w $Self->{ConfigObject}->Get($PathKey) ) {
-            $Output .= $Self->{LayoutObject}->Notify(
-                Priority => 'Error',
-                Data     => $Self->{LayoutObject}->{LanguageObject}->Translate(
-                    "%s is not writable!",
-                    "$PathKey " . $Self->{ConfigObject}->Get($PathKey),
-                ),
-                Link =>
-                    $Self->{LayoutObject}->{Baselink}
-                    . 'Action=AdminSysConfig;Subaction=Edit;SysConfigGroup=Framework;SysConfigSubGroup=Crypt::SMIME',
-            );
-        }
-    }
-    if ( !$Self->{CryptObject} && $Self->{ConfigObject}->Get('SMIME') ) {
-        $Output .= $Self->{LayoutObject}->Notify(
+    if ( $SMIMEObject && $SMIMEObject->Check() ) {
+        $Output .= $LayoutObject->Notify(
             Priority => 'Error',
-            Data     => $Self->{LayoutObject}->{LanguageObject}->Translate( "Cannot create %s!", "CryptObject" ),
-            Link =>
-                $Self->{LayoutObject}->{Baselink}
-                . 'Action=AdminSysConfig;Subaction=Edit;SysConfigGroup=Framework;SysConfigSubGroup=Crypt::SMIME',
-        );
-    }
-    if ( $Self->{CryptObject} && $Self->{CryptObject}->Check() ) {
-        $Output .= $Self->{LayoutObject}->Notify(
-            Priority => 'Error',
-            Data     => $Self->{LayoutObject}->{LanguageObject}->Translate("' . $Self->{CryptObject}->Check() . '"),
+            Data     => $LayoutObject->{LanguageObject}->Translate("' . $SMIMEObject->Check() . '"),
         );
     }
 
     for my $Message ( @{ $Param{Result} } ) {
         my $Priority = ( $Message->{Successful} ? 'Notice' : 'Error' );
-        $Output .= $Self->{LayoutObject}->Notify(
+        $Output .= $LayoutObject->Notify(
             Priority => $Priority,
             Data     => $Message->{Message},
         );
     }
 
     my @List = ();
-    if ( $Self->{CryptObject} ) {
-        @List = $Self->{CryptObject}->Search();
+    if ($SMIMEObject) {
+        @List = $SMIMEObject->Search();
     }
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block( Name => 'Overview' );
+    $LayoutObject->Block(
         Name => 'OverviewResult',
     );
     if (@List) {
@@ -623,18 +648,18 @@ sub _Overview {
                 $Attributes->{Type}    = 'Invalid';
                 $Attributes->{Subject} = "The file: '$Attributes->{Filename}' is invalid";
             }
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'Row',
                 Data => $Attributes,
             );
             if ( defined $Attributes->{Type} && $Attributes->{Type} eq 'key' ) {
-                $Self->{LayoutObject}->Block(
+                $LayoutObject->Block(
                     Name => 'CertificateRelationAdd',
                     Data => $Attributes,
                 );
             }
             elsif ( defined $Attributes->{Type} && $Attributes->{Type} eq 'cert' ) {
-                $Self->{LayoutObject}->Block(
+                $LayoutObject->Block(
                     Name => 'CertificateRead',
                     Data => $Attributes,
                 );
@@ -642,23 +667,16 @@ sub _Overview {
         }
     }
     else {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'NoDataFoundMsg',
             Data => {},
         );
     }
-    $Self->{LayoutObject}->Block(
-        Name => 'ActionList',
-    );
-    $Self->{LayoutObject}->Block(
-        Name => 'ActionAdd',
-    );
-    $Self->{LayoutObject}->Block(
-        Name => 'SMIMEFilter',
-    );
-    $Self->{LayoutObject}->Block(
-        Name => 'OverviewHint',
-    );
+
+    $LayoutObject->Block( Name => 'ActionList' );
+    $LayoutObject->Block( Name => 'ActionAdd' );
+    $LayoutObject->Block( Name => 'SMIMEFilter' );
+    $LayoutObject->Block( Name => 'OverviewHint' );
 
     return $Output;
 }
@@ -666,30 +684,35 @@ sub _Overview {
 sub _SignerCertificateOverview {
     my ( $Self, %Param ) = @_;
 
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
     if ( !$Param{CertFingerprint} ) {
-        return $Self->{LayoutObject}->ErrorScreen(
-            Message => 'Needed Fingerprint',
+        return $LayoutObject->ErrorScreen(
+            Message => Translatable('Needed Fingerprint'),
         );
     }
 
-    my @SignerCertResults = $Self->{CryptObject}->PrivateSearch(
+    my $SMIMEObject = $Kernel::OM->Get('Kernel::System::Crypt::SMIME');
+
+    my @SignerCertResults = $SMIMEObject->PrivateSearch(
         Search => $Param{CertFingerprint},
     );
     my %SignerCert;
     %SignerCert = %{ $SignerCertResults[0] } if @SignerCertResults;
 
     # get all certificates
-    my @AvailableCerts = $Self->{CryptObject}->CertificateSearch();
+    my @AvailableCerts = $SMIMEObject->CertificateSearch();
 
     # get all relations for that certificate @ActualRelations
-    my @ActualRelations = $Self->{CryptObject}->SignerCertRelationGet(
+    my @ActualRelations = $SMIMEObject->SignerCertRelationGet(
         CertFingerprint => $Param{CertFingerprint},
     );
 
     # get needed data from actual relations
     my @RelatedCerts;
     for my $RelatedCert (@ActualRelations) {
-        my @Certificate = $Self->{CryptObject}->CertificateSearch(
+        my @Certificate = $SMIMEObject->CertificateSearch(
             Search => $RelatedCert->{CAFingerprint},
         );
         push @RelatedCerts, $Certificate[0] if $Certificate[0];
@@ -702,17 +725,12 @@ sub _SignerCertificateOverview {
     @ShowCertList = grep ( !defined $RelatedCerts{ $_->{Fingerprint} }
             && $_->{Fingerprint} ne $Param{CertFingerprint}, @AvailableCerts );
 
-    $Self->{LayoutObject}->Block(
-        Name => 'ActionList',
-    );
-    $Self->{LayoutObject}->Block(
-        Name => 'ActionOverview',
-    );
-    $Self->{LayoutObject}->Block(
-        Name => 'SignerCertHint',
-    );
+    $LayoutObject->Block( Name => 'Overview' );
+    $LayoutObject->Block( Name => 'ActionList' );
+    $LayoutObject->Block( Name => 'ActionOverview' );
+    $LayoutObject->Block( Name => 'SignerCertHint' );
 
-    $Self->{LayoutObject}->Block(
+    $LayoutObject->Block(
         Name => 'SignerCertificates',
         Data => {
             CertFingerprint => $SignerCert{Subject},
@@ -721,7 +739,7 @@ sub _SignerCertificateOverview {
 
     if (@RelatedCerts) {
         for my $ActualRelation (@RelatedCerts) {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'RelatedCertsRow',
                 Data => {
                     %{$ActualRelation},
@@ -731,14 +749,14 @@ sub _SignerCertificateOverview {
         }
     }
     else {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'RelatedCertsNoDataFoundMsg',
         );
     }
 
     if (@ShowCertList) {
         for my $AvailableCert (@ShowCertList) {
-            $Self->{LayoutObject}->Block(
+            $LayoutObject->Block(
                 Name => 'AvailableCertsRow',
                 Data => {
                     %{$AvailableCert},
@@ -748,73 +766,30 @@ sub _SignerCertificateOverview {
         }
     }
     else {
-        $Self->{LayoutObject}->Block(
+        $LayoutObject->Block(
             Name => 'AvailableCertsNoDataFoundMsg',
         );
     }
 
-    my $Output = $Self->{LayoutObject}->Header();
-    $Output .= $Self->{LayoutObject}->NavigationBar();
+    my $Output = $LayoutObject->Header();
+    $Output .= $LayoutObject->NavigationBar();
 
     if ( $Param{Message} ) {
         my %Message = %{ $Param{Message} };
-        $Output .= $Self->{LayoutObject}->Notify(
+        $Output .= $LayoutObject->Notify(
             Priority => $Message{Type},
             Info     => $Message{Message},
         );
     }
 
-    # check if SMIME is activated in the sysconfig first
-    if ( !$Self->{ConfigObject}->Get('SMIME') ) {
-        $Output .= $Self->{LayoutObject}->Notify(
-            Priority => 'Error',
-            Data     => $Self->{LayoutObject}->{LanguageObject}->Translate( "Please activate %s first!", "SMIME" ),
-            Link =>
-                $Self->{LayoutObject}->{Baselink}
-                . 'Action=AdminSysConfig;Subaction=Edit;SysConfigGroup=Framework;SysConfigSubGroup=Crypt::SMIME',
-        );
-    }
-
-    # check if SMIME Paths are writable
-    for my $PathKey (qw(SMIME::CertPath SMIME::PrivatePath)) {
-        if ( !-w $Self->{ConfigObject}->Get($PathKey) ) {
-            $Output .= $Self->{LayoutObject}->Notify(
-                Priority => 'Error',
-                Data     => $Self->{LayoutObject}->{LanguageObject}->Translate(
-                    "%s is not writable!",
-                    "$PathKey " . $Self->{ConfigObject}->Get($PathKey)
-                ),
-                ,
-                Link =>
-                    $Self->{LayoutObject}->{Baselink}
-                    . 'Action=AdminSysConfig;Subaction=Edit;SysConfigGroup=Framework;SysConfigSubGroup=Crypt::SMIME',
-            );
-        }
-    }
-    if ( !$Self->{CryptObject} && $Self->{ConfigObject}->Get('SMIME') ) {
-        $Output .= $Self->{LayoutObject}->Notify(
-            Priority => 'Error',
-            Data     => $Self->{LayoutObject}->{LanguageObject}->Translate( "Cannot create %s!", "CryptObject" ),
-            Link =>
-                $Self->{LayoutObject}->{Baselink}
-                . 'Action=AdminSysConfig;Subaction=Edit;SysConfigGroup=Framework;SysConfigSubGroup=Crypt::SMIME',
-        );
-    }
-    if ( $Self->{CryptObject} && $Self->{CryptObject}->Check() ) {
-        $Output .= $Self->{LayoutObject}->Notify(
-            Priority => 'Error',
-            Data     => $Self->{LayoutObject}->{LanguageObject}->Translate("' . $Self->{CryptObject}->Check() . '"),
-        );
-    }
-
-    $Output .= $Self->{LayoutObject}->Output(
+    $Output .= $LayoutObject->Output(
         TemplateFile => 'AdminSMIME',
         Data         => {
             %Param,
             Subtitle => 'Handle Private Certificate Relations',
         },
     );
-    $Output .= $Self->{LayoutObject}->Footer();
+    $Output .= $LayoutObject->Footer();
 
     return $Output;
 }
@@ -822,29 +797,34 @@ sub _SignerCertificateOverview {
 sub _CertificateRead {
     my ( $Self, %Param ) = @_;
 
-    my $Output = $Self->{LayoutObject}->Header(
+    # get layout object
+    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
+
+    my $Output = $LayoutObject->Header(
         Value => $Param{Filename},
         Type  => 'Small',
     );
 
+    my $SMIMEObject = $Kernel::OM->Get('Kernel::System::Crypt::SMIME');
+
     # get the certificate content as plain text
-    my $CertificateText = $Self->{CryptObject}->CertificateRead(%Param);
+    my $CertificateText = $SMIMEObject->CertificateRead(%Param);
 
     return if !$CertificateText;
 
     # convert content to html string
-    $Param{CertificateText} = $Self->{LayoutObject}->Ascii2Html(
+    $Param{CertificateText} = $LayoutObject->Ascii2Html(
         Text           => $CertificateText,
         HTMLResultMode => 1,
     );
 
     $Output
-        .= $Self->{LayoutObject}->Output(
+        .= $LayoutObject->Output(
         TemplateFile => 'AdminSMIMECertRead',
         Data         => \%Param
         );
 
-    $Output .= $Self->{LayoutObject}->Footer(
+    $Output .= $LayoutObject->Footer(
         Type => 'Small',
     );
     return $Output;
