@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2020 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -207,60 +207,20 @@ sub Run {
         $AgentStatisticsFrontendPermission = 1;
     }
     else {
-        my $GroupObject = $Kernel::OM->Get('Kernel::System::Group');
         TYPE:
         for my $Type (qw(GroupRo Group)) {
             my $StatsGroups = ref $StatsReg->{$Type} eq 'ARRAY' ? $StatsReg->{$Type} : [ $StatsReg->{$Type} ];
             GROUP:
             for my $StatsGroup ( @{$StatsGroups} ) {
                 next GROUP if !$StatsGroup;
-                next GROUP if !$GroupObject->PermissionCheck(
-                    UserID    => $Self->{UserID},
-                    GroupName => $StatsGroup,
-                    Type      => 'ro',
-                );
-
+                next GROUP if !$LayoutObject->{"UserIsGroupRo[$StatsGroup]"};
+                next GROUP if $LayoutObject->{"UserIsGroupRo[$StatsGroup]"} ne 'Yes';
                 $AgentStatisticsFrontendPermission = 1;
                 last TYPE;
             }
         }
     }
 
-    my $StatsResultDataJSON = $LayoutObject->JSONEncode(
-        Data     => $CachedData,
-        NoQuotes => 1,
-    );
-
-    my $StatsFormatJSON = $LayoutObject->JSONEncode(
-        Data     => $Format,
-        NoQuotes => 1,
-    );
-
-    # send data to JS
-    $LayoutObject->AddJSData(
-        Key   => 'StatsData' . $StatID,
-        Value => {
-            Name               => $Self->{Name},
-            Format             => $StatsFormatJSON,
-            StatResultData     => $StatsResultDataJSON,
-            Preferences        => $Preferences{ 'GraphWidget' . $Self->{Name} } || '{}',
-            MaxXaxisAttributes => $Kernel::OM->Get('Kernel::Config')->Get('Stats::MaxXaxisAttributes'),
-        },
-    );
-
-    if ( $Self->{UserRefreshTime} ) {
-        my $Refresh = 60 * $Self->{UserRefreshTime};
-
-        $LayoutObject->AddJSData(
-            Key   => 'WidgetRefreshStat' . $StatID,
-            Value => {
-                Name        => $Self->{Name},
-                NameHTML    => $Self->{Name},
-                RefreshTime => $Refresh,
-            },
-        );
-    }
-
     my $Content = $LayoutObject->Output(
         TemplateFile => 'AgentDashboardStats',
         Data         => {
@@ -271,9 +231,9 @@ sub Run {
             Stat                              => $Stat,
             Format                            => $Format,
             AgentStatisticsFrontendPermission => $AgentStatisticsFrontendPermission,
-            Preferences                       => $Preferences{ 'GraphWidget' . $Self->{Name} } || '{}',
+            Preferences => $Preferences{ 'GraphWidget' . $Self->{Name} } || '{}',
         },
-        AJAX => $Param{AJAX},
+        KeepScriptTags => $Param{AJAX},
     );
 
     return $Content;
