@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::Output::HTML::Preferences::Password;
@@ -62,24 +62,27 @@ sub Param {
         @Params,
         {
             %Param,
-            Key   => Translatable('Current password'),
-            Name  => 'CurPw',
-            Raw   => 1,
-            Block => 'Password'
+            Key          => Translatable('Current password'),
+            Name         => 'CurPw',
+            Raw          => 1,
+            Block        => 'Password',
+            Autocomplete => 'current-password',
         },
         {
             %Param,
-            Key   => Translatable('New password'),
-            Name  => 'NewPw',
-            Raw   => 1,
-            Block => 'Password'
+            Key          => Translatable('New password'),
+            Name         => 'NewPw',
+            Raw          => 1,
+            Block        => 'Password',
+            Autocomplete => 'new-password',
         },
         {
             %Param,
-            Key   => Translatable('Verify password'),
-            Name  => 'NewPw1',
-            Raw   => 1,
-            Block => 'Password'
+            Key          => Translatable('Verify password'),
+            Name         => 'NewPw1',
+            Raw          => 1,
+            Block        => 'Password',
+            Autocomplete => 'new-password',
         },
     );
 
@@ -98,7 +101,7 @@ sub Param {
             Key   => '2 Factor Token',
             Name  => 'TwoFactorToken',
             Raw   => 1,
-            Block => 'Password',
+            Block => 'Input',
         };
 
         last COUNT;
@@ -144,9 +147,6 @@ sub Run {
     my $AuthObject = $Kernel::OM->Get( 'Kernel::System::' . $AuthModule );
     return 1 if !$AuthObject;
 
-    # get layout object
-    my $LayoutObject = $Kernel::OM->Get('Kernel::Output::HTML::Layout');
-
     # validate current password
     if (
         !$AuthObject->Auth(
@@ -183,7 +183,7 @@ sub Run {
 
     # check min size of password
     if ( $Config->{PasswordMinSize} && length $Pw < $Config->{PasswordMinSize} ) {
-        $Self->{Error} = Translatable(
+        $Self->{Error} = $Kernel::OM->Get('Kernel::Output::HTML::Layout')->{LanguageObject}->Translate(
             'Can\'t update password, it must be at least %s characters long!',
             $Config->{PasswordMinSize}
         );
