@@ -1,10 +1,9 @@
 # --
-# Kernel/System/DynamicField.pm - DynamicFields configuration backend
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::DynamicField;
@@ -303,7 +302,7 @@ sub DynamicFieldGet {
     my %Data;
     while ( my @Data = $DBObject->FetchrowArray() ) {
 
-        my $Config = $YAMLObject->Load( Data => $Data[7] ) || {};
+        my $Config = $YAMLObject->Load( Data => $Data[7] );
 
         %Data = (
             ID            => $Data[0],
@@ -320,13 +319,21 @@ sub DynamicFieldGet {
         );
     }
 
-    # set cache
-    $CacheObject->Set(
-        Type  => 'DynamicField',
-        Key   => $CacheKey,
-        Value => \%Data,
-        TTL   => $Self->{CacheTTL},
-    );
+    if (%Data) {
+
+        # Set the cache only, if the YAML->Load was successful (see bug#12483).
+        if ( $Data{Config} ) {
+
+            $CacheObject->Set(
+                Type  => 'DynamicField',
+                Key   => $CacheKey,
+                Value => \%Data,
+                TTL   => $Self->{CacheTTL},
+            );
+        }
+
+        $Data{Config} ||= {};
+    }
 
     return \%Data;
 }
@@ -373,8 +380,10 @@ sub DynamicFieldUpdate {
         $Reorder = 1;
     }
 
+    my $YAMLObject = $Kernel::OM->Get('Kernel::System::YAML');
+
     # dump config as string
-    my $Config = $Kernel::OM->Get('Kernel::System::YAML')->Dump(
+    my $Config = $YAMLObject->Dump(
         Data => $Param{Config},
     );
 
@@ -382,6 +391,8 @@ sub DynamicFieldUpdate {
     #    part of the data already had it.
     utf8::upgrade($Config);
 
+    return if !$YAMLObject->Load( Data => $Config );
+
     # check needed structure for some fields
     if ( $Param{Name} !~ m{ \A [a-zA-Z\d]+ \z }xms ) {
         $Kernel::OM->Get('Kernel::System::Log')->Log(
@@ -623,7 +634,7 @@ sub DynamicFieldList {
             next FIELDNAME if !IsHashRefWithData($FieldConfig);
             next FIELDNAME if !$FieldConfig->{ID};
 
-            $AllowedFieldIDs{ $FieldConfig->{ID} } = 1,
+            $AllowedFieldIDs{ $FieldConfig->{ID} } = 1;
         }
     }
 
@@ -699,7 +710,7 @@ sub DynamicFieldList {
             for my $FieldID ( sort keys %{$Cache} ) {
                 next FIELDID if !$AllowedFieldIDs{$FieldID};
 
-                $FilteredData->{$FieldID} = $Cache->{$FieldID}
+                $FilteredData->{$FieldID} = $Cache->{$FieldID};
             }
         }
 
@@ -950,7 +961,7 @@ sub DynamicFieldListGet {
             next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
             next DYNAMICFIELD if !$Param{FieldFilter}->{ $DynamicFieldConfig->{Name} };
 
-            push @{$FilteredData}, $DynamicFieldConfig,
+            push @{$FilteredData}, $DynamicFieldConfig;
         }
 
         # return filtered data from cache
@@ -1048,7 +1059,7 @@ sub DynamicFieldListGet {
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
         next DYNAMICFIELD if !$Param{FieldFilter}->{ $DynamicFieldConfig->{Name} };
 
-        push @{$FilteredData}, $DynamicFieldConfig,
+        push @{$FilteredData}, $DynamicFieldConfig;
     }
 
     # return filtered data from DB
@@ -1155,7 +1166,7 @@ sub DynamicFieldOrderCheck {
 
         # when finding a field with wrong order, set OrderError flag and exit loop
         $OrderError = 1;
-        last DYNAMICFIELD
+        last DYNAMICFIELD;
     }
 
     return if $OrderError;
@@ -1379,11 +1390,11 @@ sub _DynamicFieldReorder {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
 
