@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,12 +13,14 @@ use warnings;
 
 use base qw(Kernel::System::SupportDataCollector::PluginBase);
 
+use Kernel::Language qw(Translatable);
+
 our @ObjectDependencies = (
     'Kernel::Config',
 );
 
 sub GetDisplayPath {
-    return 'OTRS';
+    return Translatable('OTRS');
 }
 
 sub Run {
@@ -30,14 +32,14 @@ sub Run {
     # Does the SystemID contain non-digits?
     if ( $SystemID !~ /^\d+$/ ) {
         $Self->AddResultProblem(
-            Label   => 'SystemID',
+            Label   => Translatable('SystemID'),
             Value   => $SystemID,
-            Message => 'Your SystemID setting is invalid, it should only contain digits.',
+            Message => Translatable('Your SystemID setting is invalid, it should only contain digits.'),
         );
     }
     else {
         $Self->AddResultOk(
-            Label => 'SystemID',
+            Label => Translatable('SystemID'),
             Value => $SystemID,
         );
     }
@@ -45,16 +47,4 @@ sub Run {
     return $Self->GetResults();
 }
 
-=back
-
-=head1 TERMS AND CONDITIONS
-
-This software is part of the OTRS project (L<https://otrs.org/>).
-
-This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
-
-=cut
-
 1;
