@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::SystemAddress;
@@ -11,8 +11,12 @@ package Kernel::System::SystemAddress;
 use strict;
 use warnings;
 
-use Kernel::System::CacheInternal;
-use Kernel::System::Valid;
+our @ObjectDependencies = (
+    'Kernel::System::Cache',
+    'Kernel::System::DB',
+    'Kernel::System::Log',
+    'Kernel::System::Valid',
+);
 
 =head1 NAME
 
@@ -32,38 +36,9 @@ Global module to add/edit/update system addresses.
 
 create an object
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::SystemAddress;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $SystemAddressObject = Kernel::System::SystemAddress->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        EncodeObject => $EncodeObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $SystemAddressObject = $Kernel::OM->Get('Kernel::System::SystemAddress');
 
 =cut
 
@@ -74,22 +49,10 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for my $Needed (qw(ConfigObject LogObject DBObject MainObject EncodeObject)) {
-        if ( $Param{$Needed} ) {
-            $Self->{$Needed} = $Param{$Needed};
-        }
-        else {
-            die "Got no $Needed!";
-        }
-    }
+    $Self->{DBObject} = $Kernel::OM->Get('Kernel::System::DB');
 
-    $Self->{ValidObject}         = Kernel::System::Valid->new( %{$Self} );
-    $Self->{CacheInternalObject} = Kernel::System::CacheInternal->new(
-        %Param,
-        Type => 'SystemAddress',
-        TTL  => 60 * 60 * 24 * 20,
-    );
+    $Self->{CacheType} = 'SystemAddress';
+    $Self->{CacheTTL}  = 60 * 60 * 24 * 20;
 
     return $Self;
 }
@@ -115,7 +78,7 @@ sub SystemAddressAdd {
     # check needed stuff
     for my $Needed (qw(Name ValidID Realname QueueID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!"
             );
@@ -123,6 +86,15 @@ sub SystemAddressAdd {
         }
     }
 
+    # check if a system address with this name already exists
+    if ( $Self->NameExistsCheck( Name => $Param{Name} ) ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "A system address with name '$Param{Name}' already exists!"
+        );
+        return;
+    }
+
     # insert new system address
     return if !$Self->{DBObject}->Do(
         SQL => 'INSERT INTO system_address (value0, value1, valid_id, comments, queue_id, '
@@ -147,7 +119,9 @@ sub SystemAddressAdd {
         $ID = $Row[0];
     }
 
-    $Self->{CacheInternalObject}->CleanUp();
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
 
     return $ID;
 }
@@ -180,7 +154,7 @@ sub SystemAddressGet {
 
     # check needed stuff
     if ( !$Param{ID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "Need ID!"
         );
@@ -189,8 +163,9 @@ sub SystemAddressGet {
 
     my $CacheKey = 'SystemAddressGet::' . $Param{ID};
 
-    my $Cached = $Self->{CacheInternalObject}->Get(
-        Key => $CacheKey,
+    my $Cached = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
     );
 
     if ( ref $Cached eq 'HASH' ) {
@@ -220,7 +195,9 @@ sub SystemAddressGet {
         );
     }
 
-    $Self->{CacheInternalObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
         Key   => $CacheKey,
         Value => \%Data,
     );
@@ -250,7 +227,7 @@ sub SystemAddressUpdate {
     # check needed stuff
     for my $Needed (qw(ID Name ValidID Realname QueueID UserID)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!"
             );
@@ -258,6 +235,21 @@ sub SystemAddressUpdate {
         }
     }
 
+    # check if a system address with this name already exists
+    if (
+        $Self->NameExistsCheck(
+            ID   => $Param{ID},
+            Name => $Param{Name}
+        )
+        )
+    {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "A system address with name '$Param{Name}' already exists!"
+        );
+        return;
+    }
+
     # update system address
     return if !$Self->{DBObject}->Do(
         SQL => 'UPDATE system_address SET value0 = ?, value1 = ?, comments = ?, valid_id = ?, '
@@ -268,7 +260,9 @@ sub SystemAddressUpdate {
         ],
     );
 
-    $Self->{CacheInternalObject}->CleanUp();
+    $Kernel::OM->Get('Kernel::System::Cache')->CleanUp(
+        Type => $Self->{CacheType},
+    );
 
     return 1;
 }
@@ -286,7 +280,7 @@ returns:
     %List = (
         '1' => 'sales@example.com',
         '2' => 'purchasing@example.com',
-        '3' => 'support@example.com',
+        '3' => 'service@example.com',
     );
 
 =cut
@@ -301,8 +295,9 @@ sub SystemAddressList {
 
     my $CacheKey = 'SystemAddressList::' . $Valid;
 
-    my $Cached = $Self->{CacheInternalObject}->Get(
-        Key => $CacheKey,
+    my $Cached = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
     );
 
     if ( ref $Cached eq 'HASH' ) {
@@ -311,7 +306,7 @@ sub SystemAddressList {
 
     my $ValidSQL = '';
     if ($Valid) {
-        my $ValidIDs = join ',', $Self->{ValidObject}->ValidIDsGet();
+        my $ValidIDs = join ',', $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet();
         $ValidSQL = " WHERE valid_id IN ($ValidIDs)";
     }
 
@@ -329,7 +324,9 @@ sub SystemAddressList {
         $List{ $Data[0] } = $Data[1];
     }
 
-    $Self->{CacheInternalObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
         Key   => $CacheKey,
         Value => \%List,
     );
@@ -357,7 +354,7 @@ sub SystemAddressIsLocalAddress {
     # check needed stuff
     for my $Needed (qw(Address)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!"
             );
@@ -382,7 +379,7 @@ sub SystemAddressQueueID {
     # check needed stuff
     for my $Needed (qw(Address)) {
         if ( !$Param{$Needed} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $Needed!"
             );
@@ -394,8 +391,9 @@ sub SystemAddressQueueID {
     $Param{Address} =~ s/\s+//g;
 
     my $CacheKey = 'SystemAddressQueueID::' . $Param{Address};
-    my $Cached   = $Self->{CacheInternalObject}->Get(
-        Key => $CacheKey,
+    my $Cached   = $Kernel::OM->Get('Kernel::System::Cache')->Get(
+        Type => $Self->{CacheType},
+        Key  => $CacheKey,
     );
 
     if ( ref $Cached eq 'SCALAR' ) {
@@ -405,7 +403,7 @@ sub SystemAddressQueueID {
     if ( $Self->{DBObject}->GetDatabaseFunction('CaseSensitive') ) {
         return if !$Self->{DBObject}->Prepare(
             SQL => "SELECT queue_id FROM system_address WHERE "
-                . "valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) "
+                . "valid_id IN ( ${\(join ', ', $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet())} ) "
                 . "AND LOWER(value0) = LOWER(?)",
             Bind  => [ \$Param{Address} ],
             Limit => 1,
@@ -414,7 +412,7 @@ sub SystemAddressQueueID {
     else {
         return if !$Self->{DBObject}->Prepare(
             SQL => "SELECT queue_id FROM system_address WHERE "
-                . "valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} ) "
+                . "valid_id IN ( ${\(join ', ', $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet())} ) "
                 . "AND value0 = ?",
             Bind  => [ \$Param{Address} ],
             Limit => 1,
@@ -427,7 +425,9 @@ sub SystemAddressQueueID {
         $QueueID = $Row[0];
     }
 
-    $Self->{CacheInternalObject}->Set(
+    $Kernel::OM->Get('Kernel::System::Cache')->Set(
+        Type  => $Self->{CacheType},
+        TTL   => $Self->{CacheTTL},
         Key   => $CacheKey,
         Value => \$QueueID,
     );
@@ -435,16 +435,92 @@ sub SystemAddressQueueID {
     return $QueueID;
 }
 
+=item NameExistsCheck()
+
+return 1 if another system address with this name already exists
+
+    $Exist = $SystemAddressObject->NameExistsCheck(
+        Name => 'Some Address',
+        ID => 1, # optional
+    );
+
+=cut
+
+sub NameExistsCheck {
+    my ( $Self, %Param ) = @_;
+
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+    return if !$DBObject->Prepare(
+        SQL  => 'SELECT id FROM system_address WHERE value0 = ?',
+        Bind => [ \$Param{Name} ],
+    );
+
+    # fetch the result
+    my $Flag;
+    while ( my @Row = $DBObject->FetchrowArray() ) {
+        if ( !$Param{ID} || $Param{ID} ne $Row[0] ) {
+            $Flag = 1;
+        }
+    }
+
+    if ($Flag) {
+        return 1;
+    }
+
+    return 0;
+}
+
+=item SystemAddressIsUsed()
+
+Return 1 if system address is used in one of the queue's.
+
+    $SytemAddressIsUsed = $SystemAddressObject->SystemAddressIsUsed(
+        SystemAddressID => 1,
+    );
+
+=cut
+
+sub SystemAddressIsUsed {
+    my ( $Self, %Param ) = @_;
+
+    # Check needed param.
+    if ( !$Param{SystemAddressID} ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need SystemAddressID!"
+        );
+        return;
+    }
+
+    # Get database object.
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
+        SQL   => 'SELECT id FROM queue WHERE system_address_id = ?',
+        Bind  => [ \$Param{SystemAddressID} ],
+        Limit => 1,
+    );
+
+    # Fetch the result.
+    my $SystemAddressIsUsed;
+    while ( my @Row = $DBObject->FetchrowArray() ) {
+        $SystemAddressIsUsed = $Row[0] ? 1 : 0;
+    }
+
+    return $SystemAddressIsUsed;
+}
+
 1;
 
 =back
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
