@@ -1,10 +1,9 @@
 # --
-# Kernel/System/Ticket/ColumnFilter.pm - all column filter functions
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (AGPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+# the enclosed file COPYING for license information (GPL). If you
+# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 # --
 
 package Kernel::System::Ticket::ColumnFilter;
@@ -741,7 +740,7 @@ sub OwnerFilterValuesGet {
 
 =item ResponsibleFilterValuesGet()
 
-get a list of ticket responsibles within the given ticket is list
+get a list of agents responsible for the tickets within the given ticket list
 
     my $Values = $ColumnFilterObject->ResponsibleFilterValuesGet(
         TicketIDs => [23, 1, 56, 74],                    # array ref list of ticket IDs
@@ -1010,45 +1009,45 @@ sub _TicketIDStringGet {
 
     my $ColumnName = $Param{ColumnName} || 't.id';
 
+    if ( !$Param{TicketIDs} || ref $Param{TicketIDs} ne 'ARRAY' || !@{ $Param{TicketIDs} } ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => "Need TicketIDs.",
+        );
+        return;
+    }
+
+    # sort ids to cache the SQL query
+    my @SortedIDs = sort { $a <=> $b } @{ $Param{TicketIDs} };
+
+    # Error out if some values were not integers.
+    @SortedIDs = map { $Kernel::OM->Get('Kernel::System::DB')->Quote( $_, 'Integer' ) } @SortedIDs;
+    return if scalar @SortedIDs != scalar @{ $Param{TicketIDs} };
+
     my $TicketIDString = '';
-    if ( IsArrayRefWithData( $Param{TicketIDs} ) ) {
 
-        # get database object
-        my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+    # split IN statement with more than 900 elements in more statements bombined with OR
+    # because Oracle doesn't support more than 1000 elements in one IN statement.
+    my @SQLStrings;
+    while ( scalar @SortedIDs ) {
 
-        # sort ids to cache the SQL query
-        my @SortedIDs = sort { $a <=> $b } @{ $Param{TicketIDs} };
+        # remove section in the array
+        my @SortedIDsPart = splice @SortedIDs, 0, 900;
 
-        # quote values
-        SORTEDID:
-        for my $TicketID (@SortedIDs) {
-            next SORTEDID if !defined $DBObject->Quote( $TicketID, 'Integer' );
-        }
+        # link together IDs
+        my $IDString = join ', ', @SortedIDsPart;
 
-        # split IN statement with more than 900 elements in more statements bombined with OR
-        # because Oracle doesn't support more than 1000 elements in one IN statement.
-        my @SQLStrings;
-        while ( scalar @SortedIDs ) {
+        # add new statement
+        push @SQLStrings, " $ColumnName IN ($IDString) ";
+    }
 
-            # remove section in the array
-            my @SortedIDsPart = splice @SortedIDs, 0, 900;
-
-            # link together IDs
-            my $IDString = join ',', @SortedIDsPart;
-
-            # add new statement
-            push @SQLStrings, " $ColumnName IN ($IDString) ";
-        }
-
-        my $SQLString = join ' OR ', @SQLStrings;
-
-        if ( $Param{IncludeAdd} ) {
-            $TicketIDString .= ' AND ( ' . $SQLString . ' ) ';
-        }
-        else {
-            $TicketIDString = $SQLString
-        }
+    my $SQLString = join ' OR ', @SQLStrings;
 
+    if ( $Param{IncludeAdd} ) {
+        $TicketIDString .= ' AND ( ' . $SQLString . ' ) ';
+    }
+    else {
+        $TicketIDString = $SQLString;
     }
 
     return $TicketIDString;
@@ -1062,10 +1061,10 @@ sub _TicketIDStringGet {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<http://otrs.org/>).
+This software is part of the OTRS project (L<https://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (AGPL). If you
-did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
 
 =cut
