@@ -1,7 +1,7 @@
 #!/bin/sh
 # --
 # auto_build.sh - build automatically OTRS tar, rpm and src-rpm
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 # --
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 # --
 
 echo "auto_build.sh - build OTRS release files"
-echo "Copyright (C) 2001-2018 OTRS AG, https://otrs.com/";
+echo "Copyright (C) 2001-2019 OTRS AG, https://otrs.com/";
 
 PATH_TO_CVS_SRC=$1
 PRODUCT=OTRS
@@ -100,11 +100,19 @@ cp -a $PATH_TO_CVS_SRC/* $PACKAGE_BUILD_DIR/$ARCHIVE_DIR/ || exit 1;
 # --
 # update RELEASE
 # --
+COMMIT_ID=$( cd $(dirname "$0")/../..; git rev-parse HEAD)
+if ! test $COMMIT_ID
+then
+    echo "Error: could not determine git commit id."
+    exit 1
+fi
+
 RELEASEFILE=$PACKAGE_BUILD_DIR/$ARCHIVE_DIR/RELEASE
 echo "PRODUCT = $PRODUCT" > $RELEASEFILE
 echo "VERSION = $VERSION" >> $RELEASEFILE
 echo "BUILDDATE = `date`" >> $RELEASEFILE
 echo "BUILDHOST = `hostname -f`" >> $RELEASEFILE
+echo "COMMIT_ID = $COMMIT_ID" >> $RELEASEFILE
 
 # --
 # cleanup
