@@ -1,9 +1,9 @@
 // --
-// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2019 OTRS AG, https://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
-// the enclosed file COPYING for license information (AGPL). If you
-// did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
+// the enclosed file COPYING for license information (GPL). If you
+// did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
 // --
 
 "use strict";
@@ -12,19 +12,23 @@ var Core = Core || {};
 Core.Customer = Core.Customer || {};
 
 /**
- * @namespace
- * @exports TargetNS as Core.Customer.Login
+ * @namespace Core.Customer.Login
+ * @memberof Core.Customer
+ * @author OTRS AG
  * @description
- *      This namespace contains all functions for the Customer login
+ *      This namespace contains all functions for the Customer login.
  */
 Core.Customer.Login = (function (TargetNS) {
     if (!Core.Debug.CheckDependency('Core.Customer.Login', 'Core.UI', 'Core.UI')) {
-        return;
+        return false;
     }
 
     /**
+     * @private
+     * @name ToggleLabel
+     * @memberof Core.Customer.Login
      * @function
-     * @param {DOMObject} $PopulatedInput is a filled out input filled
+     * @param {DOMObject} PopulatedInput - DOM representation of an input field
      * @description
      *      This function hides the label of the given field if there is value in the field
      *      or the field has focus, otherwise the label is made visible.
@@ -42,7 +46,11 @@ Core.Customer.Login = (function (TargetNS) {
     }
 
     /**
+     * @name Init
+     * @memberof Core.Customer.Login
      * @function
+     * @returns {Boolean} False if browser is not supported
+     * @param {Object} Options - Options, mainly passed through from the sysconfig
      * @description
      *      This function initializes the login functions.
      *      Time gets tracked in a hidden field.
@@ -68,7 +76,7 @@ Core.Customer.Login = (function (TargetNS) {
             $('#Signup').hide();
             $('#PreLogin').hide();
             $('#OldBrowser').show();
-            return;
+            return false;
         }
 
         // enable login form
@@ -76,9 +84,9 @@ Core.Customer.Login = (function (TargetNS) {
 
         $('#TimeOffset').val(Diff);
 
-        if ( $('#PreLogin').length ) {
+        if ($('#PreLogin').length) {
             $('#PreLogin form').submit();
-            return;
+            return false;
         }
 
         $Inputs
@@ -161,13 +169,13 @@ Core.Customer.Login = (function (TargetNS) {
             TargetID = $(this).attr('href');
 
             // get the target id out of the href attribute of the anchor
-            $TargetInputs = $(TargetID + ' input:not(:checked, :hidden, :radio), ' + TargetID +' a, ' + TargetID + ' button');
+            $TargetInputs = $(TargetID + ' input:not(:checked, :hidden, :radio), ' + TargetID + ' a, ' + TargetID + ' button');
 
             // give the inputs on the slide the user just leaves all a 'tabindex' of '-1'
             $(this).parentsUntil('#SlideArea').last().find('input:not(:checked, :hidden, :radio), a, button').attr('tabindex', -1);
 
             // give all inputs on the new shown slide an increasing 'tabindex'
-            for (I; I< $TargetInputs.length; I++) {
+            for (I; I < $TargetInputs.length; I++) {
                 $TargetInputs.eq(I).attr('tabindex', I + 1);
             }
         });
